import { AxiosError } from 'axios'
import { useQuery as useRQ, UseQueryOptions } from 'react-query'

import { Formalization, Pattern } from 'src/models'
import axiosService from 'src/services/axios-service'

export namespace GetFormalizationsQuery {
  export type Params = { patternId: Pattern['id'] }

  export type Response = Formalization[]

  export const key = ['formalizations']

  export const getKey = (params: Params) => [...key, params]

  export const queryFn = (params: Params) =>
    axiosService
      .get<Response>(`/pattern/${params.patternId}/formalizations`)
      .then((res) => res.data)

  export const useQuery = <Select = Response>(
    params: Params,
    options: UseQueryOptions<Response, AxiosError, Select> = {}
  ) => {
    return useRQ(getKey(params), () => queryFn(params), {
      ...options,
    })
  }
}
