import {
  ButtonProps,
  Tooltip,
  useDisclosure,
  Text,
  Modal,
  ModalOverlay,
  ModalContent,
  ModalHeader,
  ModalCloseButton,
  ModalBody,
  ModalFooter,
  HStack,
  Button,
} from '@chakra-ui/react'
import React from 'react'
import { Implementation, Pattern } from 'src/models'
import { RunTestsMutation } from '../query-builder/run-tests-mutation'

export type RunTestsButtonProps = {
  implementation: Implementation
  pattern: Pattern
  hasTooltip?: boolean
  children: React.ReactElement<ButtonProps>
}

export const RunTestsButton: React.FC<RunTestsButtonProps> = ({
  implementation,
  pattern,
  hasTooltip = false,
  children,
}) => {
  const { isOpen, onOpen, onClose } = useDisclosure()

  const runTestsMutation = RunTestsMutation.useMutation({
    onSuccess: (result) => console.log(result),
  })

  const handleOnRunTests = () => {
    runTestsMutation.mutate({ id: implementation.id })
  }

  const btn = React.cloneElement(children, { onClick: onOpen })

  const isValid = true
  return (
    <>
      <Tooltip isDisabled={!hasTooltip} label={<Text>Correr tests</Text>}>
        {btn}
      </Tooltip>

      <Modal isOpen={isOpen} onClose={onClose}>
        <ModalOverlay />
        <ModalContent>
          <ModalHeader>
            <Text fontSize="md">
              Correr tests de la implementacion {implementation.name} del patron{' '}
              {pattern.name}
            </Text>
          </ModalHeader>
          <ModalCloseButton mt="-2" mr="-2" />
          <ModalBody>
            <Text>this is a big TODO</Text>
          </ModalBody>
          <ModalFooter>
            <HStack>
              <Button variant="outline" onClick={onClose}>
                Cancelar
              </Button>
              <Button
                onClick={handleOnRunTests}
                variant="solid"
                colorScheme="blue"
                type="submit"
                isDisabled={!isValid}
              >
                Correr
              </Button>
            </HStack>
          </ModalFooter>
        </ModalContent>
      </Modal>
    </>
  )
}
